import { CallClientState } from "../../calling-stateful-client/src";
import { CallingBaseSelectorProps } from './baseSelectors';
import { CaptionsInformation, SupportedCaptionLanguage, SupportedSpokenLanguage } from "../../react-components/src";
import { RealTimeTextInformation } from "../../react-components/src";
/**
 * Selector type for the {@link StartCaptionsButton} component.
 * @public
 */
export type StartCaptionsButtonSelector = (state: CallClientState, props: CallingBaseSelectorProps) => {
    checked: boolean;
    currentCaptionLanguage: string;
    currentSpokenLanguage: string;
};
/**
 * Selector for {@link StartCaptionsButton} component.
 *
 * @public
 */
export declare const startCaptionsButtonSelector: StartCaptionsButtonSelector;
/**
 * Selector type for components for Changing caption language and spoken language
 * @public
 */
export type CaptionSettingsSelector = (state: CallClientState, props: CallingBaseSelectorProps) => {
    supportedCaptionLanguages: SupportedCaptionLanguage[];
    currentCaptionLanguage: SupportedCaptionLanguage;
    supportedSpokenLanguages: SupportedSpokenLanguage[];
    currentSpokenLanguage: SupportedSpokenLanguage;
    isCaptionsFeatureActive: boolean;
};
/**
 * Selector for Changing caption language and spoken language
 *
 * @public
 */
export declare const captionSettingsSelector: CaptionSettingsSelector;
/**
 * Selector type for the {@link CaptionsBanner} component.
 * @public
 */
export type CaptionsBannerSelector = (state: CallClientState, props: CallingBaseSelectorProps) => {
    captions: CaptionsInformation[];
    realTimeTexts: {
        completedMessages?: RealTimeTextInformation[];
        currentInProgress?: RealTimeTextInformation[];
        myInProgress?: RealTimeTextInformation;
    };
    isCaptionsOn: boolean;
    startCaptionsInProgress: boolean;
    isRealTimeTextOn: boolean;
    latestLocalRealTimeText: RealTimeTextInformation;
};
/**
 * Selector for {@link CaptionsBanner} component.
 *
 * @public
 */
export declare const captionsBannerSelector: CaptionsBannerSelector;
//# sourceMappingURL=captionsSelector.d.ts.map