// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { mergeStyles, Stack } from '@fluentui/react';
import React from 'react';
import { attachmentCardBaseStyles, attachmentCardFlexLayout, attachmentCardGirdLayout, attachmentGroupDisabled } from '../styles/AttachmentCardGroup.styles';
/**
 * @internal
 * Props for `_AttachmentCardGroup` component.
 */
export var _AttachmentCardGroupLayout;
(function (_AttachmentCardGroupLayout) {
    /**
     * Children are rendered in a grid layout with self resizing.
     */
    _AttachmentCardGroupLayout["Grid"] = "grid";
    /**
     * Children are rendered in a flex layout with no resizing.
     */
    _AttachmentCardGroupLayout["Flex"] = "flex";
})(_AttachmentCardGroupLayout || (_AttachmentCardGroupLayout = {}));
/**
 * @internal
 * Used with `_AttachmentCard` component where `_AttachmentCard` components are passed as children.
 * Renders the children equally spaced in multiple rows.
 */
export const _AttachmentCardGroup = (props) => {
    const { children, ariaLabel, attachmentGroupLayout, disabled } = props;
    if (!children) {
        return React.createElement(React.Fragment, null);
    }
    return React.createElement(Stack, { horizontal: true, className: mergeStyles(disabled && attachmentGroupDisabled, attachmentCardBaseStyles, attachmentGroupLayout === _AttachmentCardGroupLayout.Grid ? attachmentCardGirdLayout : attachmentCardFlexLayout), "aria-label": ariaLabel, role: "list" }, children);
};
//# sourceMappingURL=AttachmentCardGroup.js.map