/// <reference types="react" />
import { ControlBarButtonProps } from './ControlBarButton';
/**
 * Strings of {@link EndCallButton} that can be overridden.
 *
 * @public
 */
export interface EndCallButtonStrings {
    /**
     * Label of button
     */
    label: string;
    /** Tooltip content. */
    tooltipContent?: string;
    /** Label for leave option when ending call */
    leaveOption?: string;
    /** Label for end the whole call option when ending call */
    endCallOption?: string;
}
/**
 * Props for {@link EndCallButton}.
 *
 * @public
 */
export interface EndCallButtonProps extends ControlBarButtonProps {
    /**
     * Utility property for using this component with `communication react eventHandlers`.
     * Maps directly to the `onClick` property.
     */
    onHangUp?: (forEveryone?: boolean) => Promise<void>;
    /**
     * Set this to true to make it a split button.
     * The split arrow will trigger a contextual menu to allow end for everyone or just for the user.
     */
    enableEndCallMenu?: boolean;
    /**
     * Optional strings to override in component
     */
    strings?: EndCallButtonStrings;
}
/**
 * A button to end an ongoing call.
 *
 * Can be used with {@link ControlBar}.
 *
 * @public
 */
export declare const EndCallButton: (props: EndCallButtonProps) => JSX.Element;
//# sourceMappingURL=EndCallButton.d.ts.map