/// <reference types="react" />
import { IButtonStyles, IStackStyles } from '@fluentui/react';
/**
 * Strings for the incoming call notification component.
 *
 * @public
 */
export interface IncomingCallNotificationStrings {
    /**
     * Placeholder CallerID for the incoming call notification.
     */
    incomingCallNotificationPlaceholderId?: string;
    /**
     * Placeholder Alert for the incoming call notification.
     */
    incomingCallNotificationPlaceholderAlert?: string;
    /**
     * Aria label for the accept with audio button in the incoming call notification.
     */
    incomingCallNoticicationAcceptWithAudioAriaLabel?: string;
    /**
     * Aria label for the accept with video button in the incoming call notification.
     */
    incomingCallNoticicationAcceptWithVideoAriaLabel?: string;
    /**
     * Aria label for the reject button in the incoming call notification.
     */
    incomingCallNoticicationRejectAriaLabel?: string;
    /**
     * Label for the accept button in the incoming call notification.
     */
    incomingCallNotificationAcceptButtonLabel?: string;
    /**
     * Label for the accept with video button in the incoming call notification.
     */
    incomingCallNotificationAccceptWithVideoButtonLabel?: string;
    /**
     * label for the reject button in the incoming call notification.
     */
    incomingCallNotificationRejectButtonLabel?: string;
    /**
     * Aria label for the incoming call dismiss button
     */
    incomingCallNotificationDismissButtonAriaLabel?: string;
}
/**
 * Styles for the incoming call notification component.
 *
 * @public
 */
export interface IncomingCallNotificationStyles {
    /**
     * Styles for the accept buttons.
     */
    acceptButton?: IButtonStyles;
    /**
     * Styles for the reject button.
     */
    rejectButton?: IButtonStyles;
    /**
     * Styles for the root container.
     */
    root?: IStackStyles;
    /**
     * Styles for the avatar container.
     */
    avatarContainer?: IStackStyles;
}
/**
 * Properties for the incoming call notification component.
 *
 * @public
 */
export interface IncomingCallNotificationProps {
    /**
     * Caller's Name
     */
    callerName?: string;
    /**
     * Alert Text"
     */
    alertText?: string;
    /**
     * URL to the avatar image for the user
     */
    avatarImage?: string;
    /**
     * Size of the persona coin
     */
    personaSize?: number;
    /**
     * Callback to render the avatar
     */
    onRenderAvatar?: () => JSX.Element;
    /**
     * Callback to accept the call with audio
     */
    onAcceptWithAudio: () => void;
    /**
     * Callback to accept the call with Video
     */
    onAcceptWithVideo: () => void;
    /**
     * Callback to reject the call
     */
    onReject: () => void;
    /**
     * Callback when the notification is dismissed
     */
    onDismiss?: () => void;
    /**
     * Styles for the incoming call notification component.
     */
    styles?: IncomingCallNotificationStyles;
    /**
     * Strings for the incoming call notification component.
     */
    strings?: IncomingCallNotificationStrings;
    /**
     * Options for whether to show the accept with video button
     */
    acceptOptions: {
        showAcceptWithVideo: boolean;
    };
}
/**
 * A Notification component that is to be used to represent incoming calls to the end user.
 * Allows the user to accept or reject the incoming call.
 * @public
 */
export declare const IncomingCallNotification: (props: IncomingCallNotificationProps) => JSX.Element;
//# sourceMappingURL=IncomingCallNotification.d.ts.map