/// <reference types="react" />
/**
 * strings for phone info modal
 * @public
 */
export interface MeetingConferencePhoneInfoModalStrings {
    /**
     * Header for the phone info modal
     */
    meetingConferencePhoneInfoModalTitle: string;
    /**
     * Phone number instruction
     */
    meetingConferencePhoneInfoModalDialIn: string;
    /**
     * Meeting ID instruction
     */
    meetingConferencePhoneInfoModalMeetingId: string;
    /**
     * Wait for phone connection
     */
    meetingConferencePhoneInfoModalWait: string;
    /**
     * Toll Free Phone Label
     */
    meetingConferencePhoneInfoModalTollFree: string;
    /**
     * Toll Phone Label
     */
    meetingConferencePhoneInfoModalToll: string;
    /**
     * Toll Phone Label without geo data
     */
    meetingConferencePhoneInfoModalTollGeoData: string;
    /**
     * No phone number available message
     */
    meetingConferencePhoneInfoModalNoPhoneAvailable: string;
}
/**
 * @public
 * MeetingConferencePhoneInfoModal Component Props.
 */
export interface MeetingConferencePhoneInfoModalProps {
    conferencePhoneInfoList: ConferencePhoneInfo[];
    showModal?: boolean;
    onDismissMeetingPhoneInfoSettings?: () => void;
}
/**
 * @public
 * a component for setting spoken languages
 */
export declare const MeetingConferencePhoneInfoModal: (props: MeetingConferencePhoneInfoModalProps) => JSX.Element;
/**
 * @internal
 * format phone number link
 */
export declare const formatPhoneNumberLink: (phoneNumber: ConferencePhoneInfo) => string;
/**
 * @internal
 * format phone number
 */
export declare const formatPhoneNumberInfo: (phoneNumber: ConferencePhoneInfo, strings: MeetingConferencePhoneInfoModalStrings | undefined) => string;
/**
 * @internal
 * format meeting id
 */
export declare const formatMeetingId: (meetingId?: string) => string;
/**
 * @public
 * Information for conference phone info
 */
export interface ConferencePhoneInfo {
    phoneNumber: string;
    conferenceId: string;
    isTollFree: boolean;
    country?: string;
    city?: string;
}
//# sourceMappingURL=MeetingConferencePhoneInfo.d.ts.map