/// <reference types="react" />
import { ControlBarButtonProps } from './ControlBarButton';
import { ReactionResources } from '..';
/**
 * Reactions types for the Reaction button
 * @public
 */
export type ReactionButtonReaction = 'like' | 'heart' | 'applause' | 'laugh' | 'surprised';
/**
 * Props for {@link ReactionButton}.
 *
 * @public
 */
export interface ReactionButtonProps extends ControlBarButtonProps {
    /**
     * Optional strings to override in component
     */
    strings?: Partial<ReactionButtonStrings>;
    /**
     * Click event to send reaction to meeting
     */
    onReactionClick: (reaction: ReactionButtonReaction) => Promise<void>;
    /**
     * Reaction resource locator and parameters
     */
    reactionResources: ReactionResources;
}
/**
 * Strings of {@link ReactionButton} that can be overridden.
 *
 * @public
 */
export interface ReactionButtonStrings {
    /** Label of the button. */
    label: string;
    /** Aria label for reaction button accessibility announcement */
    ariaLabel: string;
    /** Tooltip content when the button is disabled. */
    tooltipDisabledContent?: string;
    /** Tooltip content when the button is enabled. */
    tooltipContent?: string;
    /** Tooltip content of like reaction button. */
    likeReactionTooltipContent?: string;
    /** Tooltip content of heart reaction button. */
    heartReactionTooltipContent?: string;
    /** Tooltip content of clap reaction button. */
    applauseReactionTooltipContent?: string;
    /** Tooltip content of laugh reaction button. */
    laughReactionTooltipContent?: string;
    /** Tooltip content of surprised reaction button. */
    surprisedReactionTooltipContent?: string;
}
/**
 * A button to send reactions.
 *
 * Can be used with {@link ControlBar}.
 *
 * @public
 */
export declare const ReactionButton: (props: ReactionButtonProps) => JSX.Element;
//# sourceMappingURL=ReactionButton.d.ts.map