/// <reference types="react" />
import { ControlBarButtonProps } from './ControlBarButton';
/**
 * Props for the StartRealTimeTextButton component
 * @public
 */
export interface StartRealTimeTextButtonProps extends ControlBarButtonProps {
    /**
     * Use this function to show RealTimeText UI in the calling experience.
     * Note that real time text should not be started for everyone in the call until the first real time text is received.
     */
    onStartRealTimeText: () => void;
    /**
     * If RealTimeText is on
     */
    isRealTimeTextOn: boolean;
    /**
     * Optional strings to override in component
     */
    strings?: StartRealTimeTextButtonStrings;
}
/**
 * Strings for the hold button labels
 * @public
 */
export interface StartRealTimeTextButtonStrings {
    /**
     * Label for the start Real Time Text button
     */
    label: string;
    /**
     * Content for when button is not checked, Real-Time Text is off.
     * We don't need to supply a tooltip string when RealTimeText is on, because the button will be disabled when Real-Time Text is on.
     */
    tooltipOffContent: string;
}
/**
 * a button to start RealTimeText
 * based on accessibility requirement, real time text cannot be turned off once it is on
 *
 * Can be used with {@link ControlBar}
 *
 * @param props - properties for the start RealTimeText button.
 * @public
 */
export declare const StartRealTimeTextButton: (props: StartRealTimeTextButtonProps) => JSX.Element;
export {};
//# sourceMappingURL=StartRealTimeTextButton.d.ts.map