/// <reference types="react" />
import { IIconProps } from '@fluentui/react';
/**
 * Props for {@link Banner}.
 *
 * @private
 */
export interface BannerProps {
    /**
     * Banner strings.
     */
    strings?: BannerStrings;
    /**
     * Banner icon.
     */
    iconProps?: IIconProps;
    /**
     * Callback called when the button inside banner is clicked.
     */
    onClickButton?: () => void;
    /**
     * If true, the primary button will be styled as a primary button. Default is false.
     */
    primaryButton?: boolean;
}
/**
 * All strings that may be shown on the UI in the {@link Banner}.
 *
 * @private
 */
export interface BannerStrings {
    /**
     * Banner title.
     */
    title: string;
    /**
     * Banner primary button label.
     */
    primaryButtonLabel: string;
}
/**
 * A component to show a banner in the UI.
 *
 * @private
 */
export declare const Banner: (props: BannerProps) => JSX.Element;
//# sourceMappingURL=Banner.d.ts.map