/// <reference types="react" />
import { IModalStyles } from '@fluentui/react';
/**
 * @private
 */
export interface PromptProps {
    isOpen?: boolean;
    onDismiss?: () => void;
    heading?: string;
    text?: string;
    confirmButtonLabel?: string;
    cancelButtonLabel?: string;
    closeButtonLabel?: string;
    onConfirm?: () => void;
    onCancel?: () => void;
    styles?: Partial<IModalStyles>;
}
/**
 * @private
 */
export declare const Prompt: (props: PromptProps) => JSX.Element;
/**
 * Strings used in prompt related to spotlight
 * @public
 */
export interface SpotlightPromptStrings {
    /**
     * Heading for prompt when starting spotlight on participant
     */
    startSpotlightHeading: string;
    /**
     * Text for prompt when starting spotlight on participant
     */
    startSpotlightText: string;
    /**
     * Label for button to confirm starting spotlight on local user in prompt
     */
    startSpotlightOnSelfText: string;
    /**
     * Label for button to confirm starting spotlight on participant in prompt
     */
    startSpotlightConfirmButtonLabel: string;
    /**
     * Label for button to cancel starting spotlight on participant in prompt
     */
    startSpotlightCancelButtonLabel: string;
    /**
     * Heading for prompt when stopping spotlight on participant
     */
    stopSpotlightHeading: string;
    /**
     * Heading for prompt when stopping spotlight on local user
     */
    stopSpotlightOnSelfHeading: string;
    /**
     * Heading for prompt when stopping all spotlight
     */
    stopAllSpotlightHeading: string;
    /**
     * Text for prompt when stopping spotlight on participant
     */
    stopSpotlightText: string;
    /**
     * Text for prompt when stopping spotlight on local user
     */
    stopSpotlightOnSelfText: string;
    /**
     * Text for prompt when stopping all spotlight
     */
    stopAllSpotlightText: string;
    /**
     * Label for button to confirm stopping spotlight on participant(s) in prompt
     */
    stopSpotlightConfirmButtonLabel: string;
    /**
     * Label for button to confirm stopping spotlight on local user in prompt
     */
    stopSpotlightOnSelfConfirmButtonLabel: string;
    /**
     * Label for button to cancel stopping spotlight on participant(s) in prompt
     */
    stopSpotlightCancelButtonLabel: string;
    /**
     * Label for button to close prompt
     */
    closeSpotlightPromptButtonLabel: string;
}
//# sourceMappingURL=Prompt.d.ts.map