// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import React from 'react';
import { BaseProvider } from '../common/BaseComposite';
import { ChatAdapterProvider } from './adapter/ChatAdapterProvider';
import { chatScreenContainerStyle } from './styles/Chat.styles';
import { ChatScreen } from './ChatScreen';
/**
 * A customizable UI composite for the chat experience.
 *
 * @remarks Chat composite min width and height are respectively 17.5rem and 20rem (280px and 320px, with default rem at 16px)
 *
 * @public
 */
export const ChatComposite = (props) => {
    const { adapter, options, onFetchAvatarPersonaData, onRenderTypingIndicator, onRenderMessage, onFetchParticipantMenuItems } = props;
    return React.createElement("div", { className: chatScreenContainerStyle },
        React.createElement(BaseProvider, Object.assign({}, props),
            React.createElement(ChatAdapterProvider, { adapter: adapter },
                React.createElement(ChatScreen, { options: options, onFetchAvatarPersonaData: onFetchAvatarPersonaData, onRenderTypingIndicator: onRenderTypingIndicator, onRenderMessage: onRenderMessage, onFetchParticipantMenuItems: onFetchParticipantMenuItems }))));
};
//# sourceMappingURL=ChatComposite.js.map