/// <reference types="react" />
import { CallSurvey, CallSurveyResponse } from '@azure/communication-calling';
import { CallSurveyImprovementSuggestions } from "../../../../react-components/src";
import { CallCompositeIcons } from './icons';
/** @private */
export declare const Survey: (props: {
    iconName?: keyof CallCompositeIcons;
    title: string;
    moreDetails?: string;
    disableStartCallButton?: boolean;
    isMobile?: boolean;
    onSubmitSurvey?: (survey: CallSurvey) => Promise<CallSurveyResponse | undefined>;
    /**
     * Optional callback to redirect users to custom screens when survey is done, note that default end call screen will be shown if this callback is not provided
     * This callback can be used to redirect users to different screens depending on survey state, whether it is submitted, skipped or has a problem when submitting the survey
     */
    onSurveyClosed?: (surveyState: 'sent' | 'skipped' | 'error', surveyError?: string) => void;
    onSurveySubmittedCustom?: (callId: string, surveyId: string, 
    /**
     * This is the survey results containing star survey data and API tag survey data.
     * This part of the result will always be sent to the calling sdk
     * This callback provides user with the ability to gain access to survey data
     */
    submittedSurvey: CallSurvey, 
    /**
     * This is the survey results containing free form text
     * This part of the result will not be handled by composites
     * User will need to collect and handle this information 100% on their own
     * Free form text survey is not going to show in the UI if onSurveySubmitted is not populated
     */
    improvementSuggestions: CallSurveyImprovementSuggestions) => Promise<void>;
}) => JSX.Element;
//# sourceMappingURL=Survey.d.ts.map